@@ -18,7 +18,7 @@ var CONFIGURATION_DEFAULTS = {
   tempDir: 'tmp',
   outputDir: 'output',
   dateFormat: 'YYYY-MM-DD',
-  languages: ['javascript']
+  languages: []
 };
 
 module.exports = function(config, params) {
@@ -42,7 +42,7 @@ module.exports = function(config, params) {
   );
 
   this.layerGrouping = new models.LayerGrouping((configuration.layerGroups || {})[this.parameters.layerGroup]);
-  this.developerInfo = new models.DeveloperInfo(configuration.contributors);
+  this.developersInfo = new models.DevelopersInfo(configuration.contributors);
 
   this.languages = _.map(configuration.languages, function(lang) {
     if (_.isUndefined(models.LanguageDefinitions.getDefinition(lang))) {
