@@ -22,9 +22,10 @@ module.exports = function(manifest) {
       diagramSelectionTitle: 'Trend metric',
       dateRange: manifest.parseDateRange()
     },
-    graphModels: [
+    graphModels: manifest.selectAvailableGraphs([
       {
         id: 'system-evolution-revisions',
+        diagramName: 'revisions-trend',
         label: 'Revisions',
         dataFile: _.find(manifest.dataFiles, { fileType: 'revisions-trend' }),
         controlTemplates: {
@@ -91,6 +92,7 @@ module.exports = function(manifest) {
       },
       {
         id: 'system-evolution-churn',
+        diagramName: 'churn-trend',
         label: 'Code churn',
         dataFile: _.find(manifest.dataFiles, { fileType: 'churn-trend' }),
         controlTemplates: {
@@ -176,6 +178,7 @@ module.exports = function(manifest) {
       },
       {
         id: 'system-evolution-coupling',
+        diagramName: 'coupling-trend',
         label: 'Coupling',
         dataFile: _.find(manifest.dataFiles, { fileType: 'coupling-trend' }),
         diagram: {
@@ -212,6 +215,6 @@ module.exports = function(manifest) {
           }
         }
       }
-    ]
+    ])
   };
 };
